@@ -30,25 +30,18 @@
 #define DEBUG 1
 #include "gstvaapidebug.h"
 
-/* Ensure those symbols are actually defined in the resulting libraries */
-#undef gst_vaapi_buffer_proxy_ref
-#undef gst_vaapi_buffer_proxy_unref
-#undef gst_vaapi_buffer_proxy_replace
-
 guint
 from_GstVaapiBufferMemoryType (guint type)
 {
   guint va_type;
 
   switch (type) {
-#if VA_CHECK_VERSION(0,36,0)
     case GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF:
       va_type = VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME;
       break;
     case GST_VAAPI_BUFFER_MEMORY_TYPE_GEM_BUF:
       va_type = VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM;
       break;
-#endif
     default:
       va_type = 0;
       break;
@@ -62,14 +55,12 @@ to_GstVaapiBufferMemoryType (guint va_type)
   guint type;
 
   switch (va_type) {
-#if VA_CHECK_VERSION(0,36,0)
     case VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME:
       type = GST_VAAPI_BUFFER_MEMORY_TYPE_DMA_BUF;
       break;
     case VA_SURFACE_ATTRIB_MEM_TYPE_KERNEL_DRM:
       type = GST_VAAPI_BUFFER_MEMORY_TYPE_GEM_BUF;
       break;
-#endif
     default:
       type = 0;
       break;
@@ -77,7 +68,6 @@ to_GstVaapiBufferMemoryType (guint va_type)
   return type;
 }
 
-#if VA_CHECK_VERSION (0,36,0)
 static gboolean
 gst_vaapi_buffer_proxy_acquire_handle (GstVaapiBufferProxy * proxy)
 {
@@ -101,7 +91,6 @@ gst_vaapi_buffer_proxy_acquire_handle (GstVaapiBufferProxy * proxy)
   return TRUE;
 }
 
-/* VA_CHECK_VERSION (0,36,0) */
 static gboolean
 gst_vaapi_buffer_proxy_release_handle (GstVaapiBufferProxy * proxy)
 {
@@ -122,7 +111,6 @@ gst_vaapi_buffer_proxy_release_handle (GstVaapiBufferProxy * proxy)
   return TRUE;
 }
 
-/* VA_CHECK_VERSION (0,36,0) */
 static void
 gst_vaapi_buffer_proxy_finalize (GstVaapiBufferProxy * proxy)
 {
@@ -140,7 +128,6 @@ gst_vaapi_buffer_proxy_finalize (GstVaapiBufferProxy * proxy)
   gst_vaapi_object_replace (&proxy->parent, NULL);
 }
 
-/* VA_CHECK_VERSION (0,36,0) */
 static inline const GstVaapiMiniObjectClass *
 gst_vaapi_buffer_proxy_class (void)
 {
@@ -150,13 +137,11 @@ gst_vaapi_buffer_proxy_class (void)
   };
   return &GstVaapiBufferProxyClass;
 }
-#endif
 
 GstVaapiBufferProxy *
 gst_vaapi_buffer_proxy_new (guintptr handle, guint type, gsize size,
     GDestroyNotify destroy_func, gpointer user_data)
 {
-#if VA_CHECK_VERSION (0,36,0)
   GstVaapiBufferProxy *proxy;
 
   g_return_val_if_fail (handle != 0, NULL);
@@ -185,19 +170,15 @@ gst_vaapi_buffer_proxy_new (guintptr handle, guint type, gsize size,
 error_unsupported_mem_type:
   {
     GST_ERROR ("unsupported buffer type (%d)", proxy->type);
-    gst_vaapi_buffer_proxy_unref_internal (proxy);
+    gst_vaapi_buffer_proxy_unref (proxy);
     return NULL;
   }
-#else
-  return NULL;
-#endif
 }
 
 GstVaapiBufferProxy *
 gst_vaapi_buffer_proxy_new_from_object (GstVaapiObject * object,
     VABufferID buf_id, guint type, GDestroyNotify destroy_func, gpointer data)
 {
-#if VA_CHECK_VERSION (0,36,0)
   GstVaapiBufferProxy *proxy;
 
   g_return_val_if_fail (object != NULL, NULL);
@@ -225,18 +206,15 @@ gst_vaapi_buffer_proxy_new_from_object (GstVaapiObject * object,
 error_unsupported_mem_type:
   {
     GST_ERROR ("unsupported buffer type (%d)", proxy->type);
-    gst_vaapi_buffer_proxy_unref_internal (proxy);
+    gst_vaapi_buffer_proxy_unref (proxy);
     return NULL;
   }
 error_acquire_handle:
   {
     GST_ERROR ("failed to acquire the underlying VA buffer handle");
-    gst_vaapi_buffer_proxy_unref_internal (proxy);
+    gst_vaapi_buffer_proxy_unref (proxy);
     return NULL;
   }
-#else
-  return NULL;
-#endif
 }
 
 /**
@@ -252,7 +230,8 @@ gst_vaapi_buffer_proxy_ref (GstVaapiBufferProxy * proxy)
 {
   g_return_val_if_fail (proxy != NULL, NULL);
 
-  return gst_vaapi_buffer_proxy_ref_internal (proxy);
+  return (GstVaapiBufferProxy *)
+      gst_vaapi_mini_object_ref (GST_VAAPI_MINI_OBJECT (proxy));
 }
 
 /**
@@ -267,7 +246,7 @@ gst_vaapi_buffer_proxy_unref (GstVaapiBufferProxy * proxy)
 {
   g_return_if_fail (proxy != NULL);
 
-  gst_vaapi_buffer_proxy_unref_internal (proxy);
+  gst_vaapi_mini_object_unref (GST_VAAPI_MINI_OBJECT (proxy));
 }
 
 /**
@@ -285,7 +264,8 @@ gst_vaapi_buffer_proxy_replace (GstVaapiBufferProxy ** old_proxy_ptr,
 {
   g_return_if_fail (old_proxy_ptr != NULL);
 
-  gst_vaapi_buffer_proxy_replace_internal (old_proxy_ptr, new_proxy);
+  gst_vaapi_mini_object_replace ((GstVaapiMiniObject **) (old_proxy_ptr),
+      GST_VAAPI_MINI_OBJECT (new_proxy));
 }
 
 /**
@@ -317,11 +297,7 @@ gst_vaapi_buffer_proxy_get_handle (GstVaapiBufferProxy * proxy)
 {
   g_return_val_if_fail (proxy != NULL, 0);
 
-#if VA_CHECK_VERSION (0,36,0)
   return GST_VAAPI_BUFFER_PROXY_HANDLE (proxy);
-#else
-  return 0;
-#endif
 }
 
 /**
@@ -337,11 +313,7 @@ gst_vaapi_buffer_proxy_get_size (GstVaapiBufferProxy * proxy)
 {
   g_return_val_if_fail (proxy != NULL, 0);
 
-#if VA_CHECK_VERSION (0,36,0)
   return GST_VAAPI_BUFFER_PROXY_SIZE (proxy);
-#else
-  return 0;
-#endif
 }
 
 /**
