@@ -133,9 +133,13 @@ context_ensure_surfaces (GstVaapiContext * context)
   GstVaapiSurface *surface;
   guint i;
 
+  if (!ensure_formats (context))
+    return FALSE;
+
   for (i = context->surfaces->len; i < num_surfaces; i++) {
-    surface = gst_vaapi_surface_new (GST_VAAPI_OBJECT_DISPLAY (context),
-        cip->chroma_type, cip->width, cip->height);
+    surface =
+        gst_vaapi_surface_new_from_formats (GST_VAAPI_OBJECT_DISPLAY (context),
+        cip->chroma_type, cip->width, cip->height, context->formats);
     if (!surface)
       return FALSE;
     gst_vaapi_surface_set_parent_context (surface, context);
@@ -298,7 +302,6 @@ config_create (GstVaapiContext * context)
         attrib = &attribs[++attrib_index];
         g_assert (attrib_index < G_N_ELEMENTS (attribs));
       }
-#if VA_CHECK_VERSION(0,37,0)
       if (cip->profile == GST_VAAPI_PROFILE_JPEG_BASELINE) {
         attrib->type = VAConfigAttribEncJPEG;
         if (!context_get_attribute (context, attrib->type, &value))
@@ -307,7 +310,6 @@ config_create (GstVaapiContext * context)
         attrib = &attribs[++attrib_index];
         g_assert (attrib_index < G_N_ELEMENTS (attribs));
       }
-#endif
 #if VA_CHECK_VERSION(0,39,1)
       if (config->roi_capability) {
         VAConfigAttribValEncROI *roi_config;
@@ -316,10 +318,14 @@ config_create (GstVaapiContext * context)
         if (!context_get_attribute (context, attrib->type, &value))
           goto cleanup;
         roi_config = (VAConfigAttribValEncROI *) & value;
-        if (roi_config->bits.num_roi_regions != config->roi_num_supported ||
-            VA_ROI_RC_QP_DELTA_SUPPORT (roi_config) == 0) {
-          GST_ERROR ("Mismatched ROI support: number of regions supported: %d"
-              " ROI delta QP: %d", roi_config->bits.num_roi_regions,
+        if (roi_config->bits.num_roi_regions != config->roi_num_supported) {
+          GST_ERROR ("Mismatched ROI support: number of regions supported: %d",
+              roi_config->bits.num_roi_regions);
+          goto cleanup;
+        }
+        if (config->rc_mode != GST_VAAPI_RATECONTROL_CQP
+            && VA_ROI_RC_QP_DELTA_SUPPORT (roi_config) == 0) {
+          GST_ERROR ("Mismatched ROI support:  ROI delta QP: %d",
               VA_ROI_RC_QP_DELTA_SUPPORT (roi_config));
           goto cleanup;
         }
@@ -527,12 +533,12 @@ gst_vaapi_context_reset (GstVaapiContext * context,
   if (reset_config)
     context_destroy (context);
 
+  if (reset_config && !(config_create (context) && context_create (context)))
+    return FALSE;
   if (reset_surfaces && !context_create_surfaces (context))
     return FALSE;
   else if (grow_surfaces && !context_ensure_surfaces (context))
     return FALSE;
-  if (reset_config && !(config_create (context) && context_create (context)))
-    return FALSE;
   return TRUE;
 }
 
