@@ -32,8 +32,12 @@
 
 G_BEGIN_DECLS
 
+#define GST_TYPE_VAAPI_DECODER \
+    (gst_vaapi_decoder_get_type ())
 #define GST_VAAPI_DECODER(obj) \
-    ((GstVaapiDecoder *)(obj))
+    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_VAAPI_DECODER, GstVaapiDecoder))
+#define GST_VAAPI_IS_DECODER(obj) \
+    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_VAAPI_DECODER))
 
 typedef struct _GstVaapiDecoder GstVaapiDecoder;
 typedef void (*GstVaapiDecoderStateChangedFunc) (GstVaapiDecoder * decoder,
@@ -73,11 +77,8 @@ typedef enum {
   GST_VAAPI_DECODER_STATUS_ERROR_UNKNOWN = -1
 } GstVaapiDecoderStatus;
 
-GstVaapiDecoder *
-gst_vaapi_decoder_ref (GstVaapiDecoder * decoder);
-
-void
-gst_vaapi_decoder_unref (GstVaapiDecoder * decoder);
+GType
+gst_vaapi_decoder_get_type (void) G_GNUC_CONST;
 
 void
 gst_vaapi_decoder_replace (GstVaapiDecoder ** old_decoder_ptr,
@@ -141,6 +142,10 @@ gst_vaapi_decoder_check_status (GstVaapiDecoder * decoder);
 gboolean
 gst_vaapi_decoder_update_caps (GstVaapiDecoder * decoder, GstCaps * caps);
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVaapiDecoder, gst_object_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* GST_VAAPI_DECODER_H */
