@@ -26,7 +26,6 @@
  */
 
 #include "sysdeps.h"
-#include <string.h>
 #include <gst/base/gstbitreader.h>
 #include <gst/codecparsers/gstmpegvideoparser.h>
 #include "gstvaapidecoder_mpeg2.h"
@@ -296,6 +295,9 @@ struct _GstVaapiDecoderMpeg2Class
   GstVaapiDecoderClass parent_class;
 };
 
+G_DEFINE_TYPE (GstVaapiDecoderMpeg2, gst_vaapi_decoder_mpeg2,
+    GST_TYPE_VAAPI_DECODER);
+
 static void
 gst_vaapi_decoder_mpeg2_close (GstVaapiDecoderMpeg2 * decoder)
 {
@@ -358,6 +360,14 @@ gst_vaapi_decoder_mpeg2_create (GstVaapiDecoder * base_decoder)
   return TRUE;
 }
 
+static GstVaapiDecoderStatus
+gst_vaapi_decoder_mpeg2_reset (GstVaapiDecoder * base_decoder)
+{
+  gst_vaapi_decoder_mpeg2_destroy (base_decoder);
+  gst_vaapi_decoder_mpeg2_create (base_decoder);
+  return GST_VAAPI_DECODER_STATUS_SUCCESS;
+}
+
 static inline void
 copy_quant_matrix (guint8 dst[64], const guint8 src[64])
 {
@@ -1564,18 +1574,24 @@ gst_vaapi_decoder_mpeg2_flush (GstVaapiDecoder * base_decoder)
   return GST_VAAPI_DECODER_STATUS_SUCCESS;
 }
 
+static void
+gst_vaapi_decoder_mpeg2_finalize (GObject * object)
+{
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (object);
+
+  gst_vaapi_decoder_mpeg2_destroy (base_decoder);
+  G_OBJECT_CLASS (gst_vaapi_decoder_mpeg2_parent_class)->finalize (object);
+}
+
 static void
 gst_vaapi_decoder_mpeg2_class_init (GstVaapiDecoderMpeg2Class * klass)
 {
-  GstVaapiMiniObjectClass *const object_class =
-      GST_VAAPI_MINI_OBJECT_CLASS (klass);
+  GObjectClass *const object_class = G_OBJECT_CLASS (klass);
   GstVaapiDecoderClass *const decoder_class = GST_VAAPI_DECODER_CLASS (klass);
 
-  object_class->size = sizeof (GstVaapiDecoderMpeg2);
-  object_class->finalize = (GDestroyNotify) gst_vaapi_decoder_finalize;
+  object_class->finalize = gst_vaapi_decoder_mpeg2_finalize;
 
-  decoder_class->create = gst_vaapi_decoder_mpeg2_create;
-  decoder_class->destroy = gst_vaapi_decoder_mpeg2_destroy;
+  decoder_class->reset = gst_vaapi_decoder_mpeg2_reset;
   decoder_class->parse = gst_vaapi_decoder_mpeg2_parse;
   decoder_class->decode = gst_vaapi_decoder_mpeg2_decode;
   decoder_class->start_frame = gst_vaapi_decoder_mpeg2_start_frame;
@@ -1583,17 +1599,12 @@ gst_vaapi_decoder_mpeg2_class_init (GstVaapiDecoderMpeg2Class * klass)
   decoder_class->flush = gst_vaapi_decoder_mpeg2_flush;
 }
 
-static inline const GstVaapiDecoderClass *
-gst_vaapi_decoder_mpeg2_class (void)
+static void
+gst_vaapi_decoder_mpeg2_init (GstVaapiDecoderMpeg2 * decoder)
 {
-  static GstVaapiDecoderMpeg2Class g_class;
-  static gsize g_class_init = FALSE;
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (decoder);
 
-  if (g_once_init_enter (&g_class_init)) {
-    gst_vaapi_decoder_mpeg2_class_init (&g_class);
-    g_once_init_leave (&g_class_init, TRUE);
-  }
-  return GST_VAAPI_DECODER_CLASS (&g_class);
+  gst_vaapi_decoder_mpeg2_create (base_decoder);
 }
 
 /**
@@ -1609,6 +1620,6 @@ gst_vaapi_decoder_mpeg2_class (void)
 GstVaapiDecoder *
 gst_vaapi_decoder_mpeg2_new (GstVaapiDisplay * display, GstCaps * caps)
 {
-  return gst_vaapi_decoder_new (gst_vaapi_decoder_mpeg2_class (),
-      display, caps);
+  return g_object_new (GST_TYPE_VAAPI_DECODER_MPEG2, "display", display,
+      "caps", caps, NULL);
 }
