@@ -24,14 +24,23 @@
 #define GST_VAAPI_DECODER_MPEG4_H
 
 #include <gst/vaapi/gstvaapidecoder.h>
-#include <gst/base/gstadapter.h>
 
 G_BEGIN_DECLS
 
+#define GST_TYPE_VAAPI_DECODER_MPEG4 \
+    (gst_vaapi_decoder_mpeg4_get_type ())
+#define GST_VAAPI_DECODER_MPEG4(decoder) \
+    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_VAAPI_DECODER_MPEG4, GstVaapiDecoderMpeg4))
+#define GST_VAAPI_IS_DECODER_MPEG4(obj) \
+    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_VAAPI_DECODER_MPEG4))
+
 typedef struct _GstVaapiDecoderMpeg4            GstVaapiDecoderMpeg4;
 
+GType
+gst_vaapi_decoder_mpeg4_get_type (void) G_GNUC_CONST;
+
 GstVaapiDecoder *
-gst_vaapi_decoder_mpeg4_new(GstVaapiDisplay *display, GstCaps *caps);
+gst_vaapi_decoder_mpeg4_new (GstVaapiDisplay *display, GstCaps *caps);
 
 G_END_DECLS
 
