@@ -26,7 +26,6 @@
  */
 
 #include "sysdeps.h"
-#include <string.h>
 #include <gst/codecparsers/gstvc1parser.h>
 #include "gstvaapidecoder_vc1.h"
 #include "gstvaapidecoder_objects.h"
@@ -98,6 +97,9 @@ struct _GstVaapiDecoderVC1Class
   GstVaapiDecoderClass parent_class;
 };
 
+G_DEFINE_TYPE (GstVaapiDecoderVC1, gst_vaapi_decoder_vc1,
+    GST_TYPE_VAAPI_DECODER);
+
 static GstVaapiDecoderStatus
 get_status (GstVC1ParserResult result)
 {
@@ -167,8 +169,7 @@ gst_vaapi_decoder_vc1_destroy (GstVaapiDecoder * base_decoder)
   gst_vaapi_decoder_vc1_close (decoder);
 
   if (priv->rbdu_buffer) {
-    g_free (priv->rbdu_buffer);
-    priv->rbdu_buffer = NULL;
+    g_clear_pointer (&priv->rbdu_buffer, g_free);
     priv->rbdu_buffer_size = 0;
   }
 }
@@ -183,12 +184,20 @@ gst_vaapi_decoder_vc1_create (GstVaapiDecoder * base_decoder)
       priv->size_changed = priv->profile_changed =
       priv->closed_entry = priv->broken_link = FALSE;
 
-  priv->profile = (GstVaapiProfile) 0;
+  priv->profile = GST_VAAPI_PROFILE_UNKNOWN;
   priv->rndctrl = 0;
   priv->width = priv->height = 0;
   return TRUE;
 }
 
+static GstVaapiDecoderStatus
+gst_vaapi_decoder_vc1_reset (GstVaapiDecoder * base_decoder)
+{
+  gst_vaapi_decoder_vc1_destroy (base_decoder);
+  gst_vaapi_decoder_vc1_create (base_decoder);
+  return GST_VAAPI_DECODER_STATUS_SUCCESS;
+}
+
 static GstVaapiDecoderStatus
 ensure_context (GstVaapiDecoderVC1 * decoder)
 {
@@ -1425,18 +1434,24 @@ gst_vaapi_decoder_vc1_flush (GstVaapiDecoder * base_decoder)
   return GST_VAAPI_DECODER_STATUS_SUCCESS;
 }
 
+static void
+gst_vaapi_decoder_vc1_finalize (GObject * object)
+{
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (object);
+
+  gst_vaapi_decoder_vc1_destroy (base_decoder);
+  G_OBJECT_CLASS (gst_vaapi_decoder_vc1_parent_class)->finalize (object);
+}
+
 static void
 gst_vaapi_decoder_vc1_class_init (GstVaapiDecoderVC1Class * klass)
 {
-  GstVaapiMiniObjectClass *const object_class =
-      GST_VAAPI_MINI_OBJECT_CLASS (klass);
+  GObjectClass *const object_class = G_OBJECT_CLASS (klass);
   GstVaapiDecoderClass *const decoder_class = GST_VAAPI_DECODER_CLASS (klass);
 
-  object_class->size = sizeof (GstVaapiDecoderVC1);
-  object_class->finalize = (GDestroyNotify) gst_vaapi_decoder_finalize;
+  object_class->finalize = gst_vaapi_decoder_vc1_finalize;
 
-  decoder_class->create = gst_vaapi_decoder_vc1_create;
-  decoder_class->destroy = gst_vaapi_decoder_vc1_destroy;
+  decoder_class->reset = gst_vaapi_decoder_vc1_reset;
   decoder_class->parse = gst_vaapi_decoder_vc1_parse;
   decoder_class->decode = gst_vaapi_decoder_vc1_decode;
   decoder_class->start_frame = gst_vaapi_decoder_vc1_start_frame;
@@ -1446,17 +1461,12 @@ gst_vaapi_decoder_vc1_class_init (GstVaapiDecoderVC1Class * klass)
   decoder_class->decode_codec_data = gst_vaapi_decoder_vc1_decode_codec_data;
 }
 
-static inline const GstVaapiDecoderClass *
-gst_vaapi_decoder_vc1_class (void)
+static void
+gst_vaapi_decoder_vc1_init (GstVaapiDecoderVC1 * decoder)
 {
-  static GstVaapiDecoderVC1Class g_class;
-  static gsize g_class_init = FALSE;
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (decoder);
 
-  if (g_once_init_enter (&g_class_init)) {
-    gst_vaapi_decoder_vc1_class_init (&g_class);
-    g_once_init_leave (&g_class_init, TRUE);
-  }
-  return GST_VAAPI_DECODER_CLASS (&g_class);
+  gst_vaapi_decoder_vc1_create (base_decoder);
 }
 
 /**
@@ -1472,5 +1482,6 @@ gst_vaapi_decoder_vc1_class (void)
 GstVaapiDecoder *
 gst_vaapi_decoder_vc1_new (GstVaapiDisplay * display, GstCaps * caps)
 {
-  return gst_vaapi_decoder_new (gst_vaapi_decoder_vc1_class (), display, caps);
+  return g_object_new (GST_TYPE_VAAPI_DECODER_VC1, "display", display,
+      "caps", caps, NULL);
 }
