@@ -83,6 +83,9 @@ struct _GstVaapiDecoderVp8Class
   GstVaapiDecoderClass parent_class;
 };
 
+G_DEFINE_TYPE (GstVaapiDecoderVp8, gst_vaapi_decoder_vp8,
+    GST_TYPE_VAAPI_DECODER);
+
 static GstVaapiDecoderStatus
 get_status (GstVp8ParserResult result)
 {
@@ -144,6 +147,15 @@ gst_vaapi_decoder_vp8_create (GstVaapiDecoder * base_decoder)
   return TRUE;
 }
 
+static GstVaapiDecoderStatus
+gst_vaapi_decoder_vp8_reset (GstVaapiDecoder * base_decoder)
+{
+  gst_vaapi_decoder_vp8_destroy (base_decoder);
+  if (gst_vaapi_decoder_vp8_create (base_decoder))
+    return GST_VAAPI_DECODER_STATUS_SUCCESS;
+  return GST_VAAPI_DECODER_STATUS_ERROR_UNKNOWN;
+}
+
 static GstVaapiDecoderStatus
 ensure_context (GstVaapiDecoderVp8 * decoder)
 {
@@ -615,18 +627,24 @@ gst_vaapi_decoder_vp8_flush (GstVaapiDecoder * base_decoder)
   return GST_VAAPI_DECODER_STATUS_SUCCESS;
 }
 
+static void
+gst_vaapi_decoder_vp8_finalize (GObject * object)
+{
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (object);
+
+  gst_vaapi_decoder_vp8_destroy (base_decoder);
+  G_OBJECT_CLASS (gst_vaapi_decoder_vp8_parent_class)->finalize (object);
+}
+
 static void
 gst_vaapi_decoder_vp8_class_init (GstVaapiDecoderVp8Class * klass)
 {
-  GstVaapiMiniObjectClass *const object_class =
-      GST_VAAPI_MINI_OBJECT_CLASS (klass);
+  GObjectClass *const object_class = G_OBJECT_CLASS (klass);
   GstVaapiDecoderClass *const decoder_class = GST_VAAPI_DECODER_CLASS (klass);
 
-  object_class->size = sizeof (GstVaapiDecoderVp8);
-  object_class->finalize = (GDestroyNotify) gst_vaapi_decoder_finalize;
+  object_class->finalize = gst_vaapi_decoder_vp8_finalize;
 
-  decoder_class->create = gst_vaapi_decoder_vp8_create;
-  decoder_class->destroy = gst_vaapi_decoder_vp8_destroy;
+  decoder_class->reset = gst_vaapi_decoder_vp8_reset;
   decoder_class->parse = gst_vaapi_decoder_vp8_parse;
   decoder_class->decode = gst_vaapi_decoder_vp8_decode;
   decoder_class->start_frame = gst_vaapi_decoder_vp8_start_frame;
@@ -634,17 +652,12 @@ gst_vaapi_decoder_vp8_class_init (GstVaapiDecoderVp8Class * klass)
   decoder_class->flush = gst_vaapi_decoder_vp8_flush;
 }
 
-static inline const GstVaapiDecoderClass *
-gst_vaapi_decoder_vp8_class (void)
+static void
+gst_vaapi_decoder_vp8_init (GstVaapiDecoderVp8 * decoder)
 {
-  static GstVaapiDecoderVp8Class g_class;
-  static gsize g_class_init = FALSE;
+  GstVaapiDecoder *const base_decoder = GST_VAAPI_DECODER (decoder);
 
-  if (g_once_init_enter (&g_class_init)) {
-    gst_vaapi_decoder_vp8_class_init (&g_class);
-    g_once_init_leave (&g_class_init, TRUE);
-  }
-  return GST_VAAPI_DECODER_CLASS (&g_class);
+  gst_vaapi_decoder_vp8_create (base_decoder);
 }
 
 /**
@@ -660,5 +673,6 @@ gst_vaapi_decoder_vp8_class (void)
 GstVaapiDecoder *
 gst_vaapi_decoder_vp8_new (GstVaapiDisplay * display, GstCaps * caps)
 {
-  return gst_vaapi_decoder_new (gst_vaapi_decoder_vp8_class (), display, caps);
+  return g_object_new (GST_TYPE_VAAPI_DECODER_VP8, "display", display,
+      "caps", caps, NULL);
 }
