@@ -118,8 +118,7 @@ gst_vaapi_decoder_vp9_close (GstVaapiDecoderVp9 * decoder)
   for (i = 0; i < GST_VP9_REF_FRAMES; i++)
     gst_vaapi_picture_replace (&priv->ref_frames[i], NULL);
 
-  if (priv->parser)
-    gst_vp9_parser_free (priv->parser);
+  g_clear_pointer (&priv->parser, gst_vp9_parser_free);
 }
 
 static gboolean
@@ -220,7 +219,16 @@ ensure_context (GstVaapiDecoderVp9 * decoder)
 
     info.profile = priv->profile;
     info.entrypoint = entrypoint;
-    info.chroma_type = GST_VAAPI_CHROMA_TYPE_YUV420;
+    if (priv->parser->bit_depth == GST_VP9_BIT_DEPTH_8) {
+      info.chroma_type = GST_VAAPI_CHROMA_TYPE_YUV420;
+    } else if (priv->parser->bit_depth == GST_VP9_BIT_DEPTH_10) {
+      info.chroma_type = GST_VAAPI_CHROMA_TYPE_YUV420_10BPP;
+    } else {
+      GST_WARNING ("VP9 with depth %d, bigger than 10BPP not supported now",
+          priv->parser->bit_depth);
+      return GST_VAAPI_DECODER_STATUS_ERROR_UNSUPPORTED_CHROMA_FORMAT;
+    }
+
     info.width = priv->width;
     info.height = priv->height;
     info.ref_frames = 8;
