@@ -24,6 +24,8 @@
 #ifndef GST_VAAPI_DISPLAY_WAYLAND_PRIV_H
 #define GST_VAAPI_DISPLAY_WAYLAND_PRIV_H
 
+#include "xdg-shell-client-protocol.h"
+
 #include <gst/vaapi/gstvaapidisplay_wayland.h>
 #include "gstvaapidisplay_priv.h"
 
@@ -60,7 +62,8 @@ struct _GstVaapiDisplayWaylandPrivate
   gchar *display_name;
   struct wl_display *wl_display;
   struct wl_compositor *compositor;
-  struct wl_shell *shell;
+  struct wl_shell *wl_shell;
+  struct xdg_wm_base *xdg_wm_base;
   struct wl_output *output;
   struct wl_registry *registry;
   guint width;
