@@ -1721,6 +1721,9 @@ add_slice_headers (GstVaapiEncoderH265 * encoder, GstVaapiEncPicture * picture,
       slice_param->num_ref_idx_l1_active_minus1 = reflist_1_count - 1;
     else
       slice_param->num_ref_idx_l1_active_minus1 = 0;
+    if (picture->type == GST_VAAPI_PICTURE_TYPE_P && encoder->low_delay_b)
+      slice_param->num_ref_idx_l1_active_minus1 =
+          slice_param->num_ref_idx_l0_active_minus1;
 
     i_ref = 0;
     if (picture->type != GST_VAAPI_PICTURE_TYPE_I) {
@@ -2058,6 +2061,7 @@ reset_properties (GstVaapiEncoderH265 * encoder)
   GstVaapiH265ReorderPool *reorder_pool;
   GstVaapiH265RefPool *ref_pool;
   guint ctu_size;
+  gboolean ret;
 
   if (encoder->idr_period < base_encoder->keyframe_period)
     encoder->idr_period = base_encoder->keyframe_period;
@@ -2067,8 +2071,9 @@ reset_properties (GstVaapiEncoderH265 * encoder)
   encoder->qp_i = encoder->init_qp;
 
   ctu_size = encoder->ctu_width * encoder->ctu_height;
-  g_assert (gst_vaapi_encoder_ensure_num_slices (base_encoder, encoder->profile,
-          encoder->entrypoint, (ctu_size + 1) / 2, &encoder->num_slices));
+  ret = gst_vaapi_encoder_ensure_num_slices (base_encoder, encoder->profile,
+      encoder->entrypoint, (ctu_size + 1) / 2, &encoder->num_slices);
+  g_assert (ret);
 
   gst_vaapi_encoder_ensure_max_num_ref_frames (base_encoder, encoder->profile,
       encoder->entrypoint);
