@@ -1799,6 +1799,46 @@ gst_vaapi_feipak_h264_finalize (GstVaapiFEIPakH264 * feipak)
 
 }
 
+static void
+set_view_ids (GstVaapiFEIPakH264 * feipak, const GValue * value)
+{
+  guint i, j;
+  guint len = gst_value_array_get_size (value);
+
+  if (len == 0)
+    goto set_default_ids;
+
+  if (len != feipak->num_views) {
+    GST_WARNING ("The view number is %d, but %d view IDs are provided. Just "
+        "fallback to use default view IDs.", feipak->num_views, len);
+    goto set_default_ids;
+  }
+
+  for (i = 0; i < len; i++) {
+    const GValue *val = gst_value_array_get_value (value, i);
+    feipak->view_ids[i] = g_value_get_uint (val);
+  }
+
+  /* check whether duplicated ID */
+  for (i = 0; i < len; i++) {
+    for (j = i + 1; j < len; j++) {
+      if (feipak->view_ids[i] == feipak->view_ids[j]) {
+        GST_WARNING ("The view %d and view %d have same view ID %d. Just "
+            "fallback to use default view IDs.", i, j, feipak->view_ids[i]);
+        goto set_default_ids;
+      }
+    }
+  }
+
+  return;
+
+set_default_ids:
+  {
+    for (i = 0; i < feipak->num_views; i++)
+      feipak->view_ids[i] = i;
+  }
+}
+
 GstVaapiEncoderStatus
 gst_vaapi_feipak_h264_set_property (GstVaapiFEIPakH264 * feipak,
     gint prop_id, const GValue * value)
@@ -1811,23 +1851,9 @@ gst_vaapi_feipak_h264_set_property (GstVaapiFEIPakH264 * feipak,
     case GST_VAAPI_FEIPAK_H264_PROP_NUM_VIEWS:
       feipak->num_views = g_value_get_uint (value);
       break;
-    case GST_VAAPI_FEIPAK_H264_PROP_VIEW_IDS:{
-      guint i;
-      GValueArray *view_ids = g_value_get_boxed (value);
-
-      if (view_ids == NULL) {
-        for (i = 0; i < feipak->num_views; i++)
-          feipak->view_ids[i] = i;
-      } else {
-        g_assert (view_ids->n_values <= feipak->num_views);
-
-        for (i = 0; i < feipak->num_views; i++) {
-          GValue *val = g_value_array_get_nth (view_ids, i);
-          feipak->view_ids[i] = g_value_get_uint (val);
-        }
-      }
+    case GST_VAAPI_FEIPAK_H264_PROP_VIEW_IDS:
+      set_view_ids (feipak, value);
       break;
-    }
     default:
       return GST_VAAPI_ENCODER_STATUS_ERROR_INVALID_PARAMETER;
   }
