@@ -30,10 +30,7 @@
 #include "gstvaapisurface_priv.h"
 #include "gstvaapiutils_core.h"
 
-#define DEBUG 1
-#include "gstvaapidebug.h"
-
-#define GST_VAAPI_FILTER(obj) \
+#define GST_VAAPI_FILTER_CAST(obj) \
     ((GstVaapiFilter *)(obj))
 
 typedef struct _GstVaapiFilterOpData GstVaapiFilterOpData;
@@ -55,7 +52,7 @@ struct _GstVaapiFilterOpData
 struct _GstVaapiFilter
 {
   /*< private > */
-  GstVaapiMiniObject parent_instance;
+  GstObject parent_instance;
 
   GstVaapiDisplay *display;
   VADisplay va_display;
@@ -73,6 +70,24 @@ struct _GstVaapiFilter
   guint use_target_rect:1;
 };
 
+typedef struct _GstVaapiFilterClass GstVaapiFilterClass;
+struct _GstVaapiFilterClass
+{
+  /*< private > */
+  GstObjectClass parent_class;
+};
+
+/* Debug category for VaapiFilter */
+GST_DEBUG_CATEGORY (gst_debug_vaapi_filter);
+#define GST_CAT_DEFAULT gst_debug_vaapi_filter
+
+#define _do_init                                                       \
+    GST_DEBUG_CATEGORY_INIT (gst_debug_vaapi_filter, "vaapifilter", 0, \
+    "VA-API Filter");
+
+G_DEFINE_TYPE_WITH_CODE (GstVaapiFilter, gst_vaapi_filter, GST_TYPE_OBJECT,
+    _do_init);
+
 /* ------------------------------------------------------------------------- */
 /* --- VPP Types                                                         --- */
 /* ------------------------------------------------------------------------- */
@@ -110,14 +125,12 @@ gst_vaapi_deinterlace_method_get_type (void)
         "Disable deinterlacing", "none"},
     {GST_VAAPI_DEINTERLACE_METHOD_BOB,
         "Bob deinterlacing", "bob"},
-#if USE_VA_VPP
     {GST_VAAPI_DEINTERLACE_METHOD_WEAVE,
         "Weave deinterlacing", "weave"},
     {GST_VAAPI_DEINTERLACE_METHOD_MOTION_ADAPTIVE,
         "Motion adaptive deinterlacing", "motion-adaptive"},
     {GST_VAAPI_DEINTERLACE_METHOD_MOTION_COMPENSATED,
         "Motion compensated deinterlacing", "motion-compensated"},
-#endif
     {0, NULL, NULL},
   };
 
@@ -156,7 +169,6 @@ gst_vaapi_deinterlace_flags_get_type (void)
 /* --- VPP Helpers                                                       --- */
 /* ------------------------------------------------------------------------- */
 
-#if USE_VA_VPP
 static VAProcFilterType *
 vpp_get_filters_unlocked (GstVaapiFilter * filter, guint * num_filters_ptr)
 {
@@ -258,16 +270,19 @@ vpp_get_filter_caps (GstVaapiFilter * filter, VAProcFilterType type,
   GST_VAAPI_DISPLAY_UNLOCK (filter->display);
   return caps;
 }
-#endif
 
 /* ------------------------------------------------------------------------- */
 /* --- VPP Operations                                                   --- */
 /* ------------------------------------------------------------------------- */
 
-#if USE_VA_VPP
 #define DEFAULT_FORMAT  GST_VIDEO_FORMAT_UNKNOWN
 #define DEFAULT_SCALING GST_VAAPI_SCALE_METHOD_DEFAULT
 
+enum
+{
+  PROP_DISPLAY = 1,
+};
+
 enum
 {
   PROP_0,
@@ -405,7 +420,6 @@ init_properties (void)
       GST_VAAPI_TYPE_SCALE_METHOD,
       DEFAULT_SCALING, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
-#if VA_CHECK_VERSION(0,36,0)
   /**
    * GstVaapiFilter:skin-tone-enhancement:
    *
@@ -415,7 +429,6 @@ init_properties (void)
       "Skin tone enhancement",
       "Apply the skin tone enhancement algorithm",
       FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-#endif
 }
 
 static void
@@ -464,12 +477,10 @@ op_data_new (GstVaapiFilterOp op, GParamSpec * pspec)
       op_data->va_cap_size = sizeof (VAProcFilterCap);
       op_data->va_buffer_size = sizeof (VAProcFilterParameterBuffer);
       break;
-#if VA_CHECK_VERSION(0,36,0)
     case GST_VAAPI_FILTER_OP_SKINTONE:
       op_data->va_type = VAProcFilterSkinToneEnhancement;
       op_data->va_buffer_size = sizeof (VAProcFilterParameterBuffer);
       break;
-#endif
     case GST_VAAPI_FILTER_OP_HUE:
       op_data->va_subtype = VAProcColorBalanceHue;
       goto op_colorbalance;
@@ -695,14 +706,12 @@ error:
     return NULL;
   }
 }
-#endif
 
 /* Determine the set of supported VPP operations by the specific
    filter, or known to this library if filter is NULL */
 static GPtrArray *
 get_operations (GstVaapiFilter * filter)
 {
-#if USE_VA_VPP
   GPtrArray *ops;
 
   if (filter && filter->operations)
@@ -712,8 +721,6 @@ get_operations (GstVaapiFilter * filter)
   if (!ops)
     return NULL;
   return filter ? get_operations_ordered (filter, ops) : ops;
-#endif
-  return NULL;
 }
 
 /* Ensure the set of supported VPP operations is cached into the
@@ -756,7 +763,6 @@ find_operation (GstVaapiFilter * filter, GstVaapiFilterOp op)
 }
 
 /* Ensure the operation's VA buffer is allocated */
-#if USE_VA_VPP
 static inline gboolean
 op_ensure_buffer (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data)
 {
@@ -766,10 +772,8 @@ op_ensure_buffer (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data)
       VAProcFilterParameterBufferType, op_data->va_buffer_size, NULL,
       &op_data->va_buffer, NULL);
 }
-#endif
 
 /* Update a generic filter (float value) */
-#if USE_VA_VPP
 static gboolean
 op_set_generic_unlocked (GstVaapiFilter * filter,
     GstVaapiFilterOpData * op_data, gfloat value)
@@ -799,7 +803,6 @@ op_set_generic_unlocked (GstVaapiFilter * filter,
   vaapi_unmap_buffer (filter->va_display, op_data->va_buffer, NULL);
   return TRUE;
 }
-#endif
 
 static inline gboolean
 op_set_generic (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
@@ -807,16 +810,13 @@ op_set_generic (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
 {
   gboolean success = FALSE;
 
-#if USE_VA_VPP
   GST_VAAPI_DISPLAY_LOCK (filter->display);
   success = op_set_generic_unlocked (filter, op_data, value);
   GST_VAAPI_DISPLAY_UNLOCK (filter->display);
-#endif
   return success;
 }
 
 /* Update the color balance filter */
-#if USE_VA_VPP
 static gboolean
 op_set_color_balance_unlocked (GstVaapiFilter * filter,
     GstVaapiFilterOpData * op_data, gfloat value)
@@ -847,7 +847,6 @@ op_set_color_balance_unlocked (GstVaapiFilter * filter,
   vaapi_unmap_buffer (filter->va_display, op_data->va_buffer, NULL);
   return TRUE;
 }
-#endif
 
 static inline gboolean
 op_set_color_balance (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
@@ -855,16 +854,13 @@ op_set_color_balance (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
 {
   gboolean success = FALSE;
 
-#if USE_VA_VPP
   GST_VAAPI_DISPLAY_LOCK (filter->display);
   success = op_set_color_balance_unlocked (filter, op_data, value);
   GST_VAAPI_DISPLAY_UNLOCK (filter->display);
-#endif
   return success;
 }
 
 /* Update deinterlace filter */
-#if USE_VA_VPP
 static gboolean
 op_set_deinterlace_unlocked (GstVaapiFilter * filter,
     GstVaapiFilterOpData * op_data, GstVaapiDeinterlaceMethod method,
@@ -900,7 +896,6 @@ op_set_deinterlace_unlocked (GstVaapiFilter * filter,
   vaapi_unmap_buffer (filter->va_display, op_data->va_buffer, NULL);
   return TRUE;
 }
-#endif
 
 static inline gboolean
 op_set_deinterlace (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
@@ -908,16 +903,13 @@ op_set_deinterlace (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
 {
   gboolean success = FALSE;
 
-#if USE_VA_VPP
   GST_VAAPI_DISPLAY_LOCK (filter->display);
   success = op_set_deinterlace_unlocked (filter, op_data, method, flags);
   GST_VAAPI_DISPLAY_UNLOCK (filter->display);
-#endif
   return success;
 }
 
 /* Update skin tone enhancement */
-#if USE_VA_VPP
 static gboolean
 op_set_skintone_unlocked (GstVaapiFilter * filter,
     GstVaapiFilterOpData * op_data, gboolean value)
@@ -939,7 +931,6 @@ op_set_skintone_unlocked (GstVaapiFilter * filter,
   vaapi_unmap_buffer (filter->va_display, op_data->va_buffer, NULL);
   return TRUE;
 }
-#endif
 
 static inline gboolean
 op_set_skintone (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
@@ -947,11 +938,9 @@ op_set_skintone (GstVaapiFilter * filter, GstVaapiFilterOpData * op_data,
 {
   gboolean success = FALSE;
 
-#if USE_VA_VPP
   GST_VAAPI_DISPLAY_LOCK (filter->display);
   success = op_set_skintone_unlocked (filter, op_data, enhance);
   GST_VAAPI_DISPLAY_UNLOCK (filter->display);
-#endif
   return success;
 }
 
@@ -1024,29 +1013,26 @@ find_format (GstVaapiFilter * filter, GstVideoFormat format)
 /* --- Interface                                                         --- */
 /* ------------------------------------------------------------------------- */
 
-#if USE_VA_VPP
-static gboolean
-gst_vaapi_filter_init (GstVaapiFilter * filter, GstVaapiDisplay * display)
+static void
+gst_vaapi_filter_init (GstVaapiFilter * filter)
 {
-  VAStatus va_status;
-
-  filter->display = gst_vaapi_display_ref (display);
-  filter->va_display = GST_VAAPI_DISPLAY_VADISPLAY (display);
   filter->va_config = VA_INVALID_ID;
   filter->va_context = VA_INVALID_ID;
   filter->format = DEFAULT_FORMAT;
 
   filter->forward_references =
       g_array_sized_new (FALSE, FALSE, sizeof (VASurfaceID), 4);
-  if (!filter->forward_references)
-    return FALSE;
 
   filter->backward_references =
       g_array_sized_new (FALSE, FALSE, sizeof (VASurfaceID), 4);
-  if (!filter->backward_references)
-    return FALSE;
+}
 
-  if (!GST_VAAPI_DISPLAY_HAS_VPP (display))
+static gboolean
+gst_vaapi_filter_initialize (GstVaapiFilter * filter)
+{
+  VAStatus va_status;
+
+  if (!filter->display)
     return FALSE;
 
   va_status = vaCreateConfig (filter->va_display, VAProfileNone,
@@ -1062,8 +1048,9 @@ gst_vaapi_filter_init (GstVaapiFilter * filter, GstVaapiDisplay * display)
 }
 
 static void
-gst_vaapi_filter_finalize (GstVaapiFilter * filter)
+gst_vaapi_filter_finalize (GObject * object)
 {
+  GstVaapiFilter *const filter = GST_VAAPI_FILTER (object);
   guint i;
 
   GST_VAAPI_DISPLAY_LOCK (filter->display);
@@ -1103,18 +1090,69 @@ gst_vaapi_filter_finalize (GstVaapiFilter * filter)
     g_array_unref (filter->formats);
     filter->formats = NULL;
   }
+
+  G_OBJECT_CLASS (gst_vaapi_filter_parent_class)->finalize (object);
 }
 
-static inline const GstVaapiMiniObjectClass *
-gst_vaapi_filter_class (void)
+static void
+gst_vaapi_filter_set_property (GObject * object, guint property_id,
+    const GValue * value, GParamSpec * pspec)
 {
-  static const GstVaapiMiniObjectClass GstVaapiFilterClass = {
-    sizeof (GstVaapiFilter),
-    (GDestroyNotify) gst_vaapi_filter_finalize
-  };
-  return &GstVaapiFilterClass;
+  GstVaapiFilter *const filter = GST_VAAPI_FILTER (object);
+
+  switch (property_id) {
+    case PROP_DISPLAY:{
+      GstVaapiDisplay *display = g_value_get_object (value);;
+
+      if (display) {
+        if (GST_VAAPI_DISPLAY_HAS_VPP (display)) {
+          filter->display = gst_object_ref (display);
+          filter->va_display = GST_VAAPI_DISPLAY_VADISPLAY (filter->display);
+        } else {
+          GST_WARNING_OBJECT (filter, "VA display doesn't support VPP");
+        }
+      }
+      break;
+    }
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+  }
+}
+
+static void
+gst_vaapi_filter_get_property (GObject * object, guint property_id,
+    GValue * value, GParamSpec * pspec)
+{
+  GstVaapiFilter *const filter = GST_VAAPI_FILTER (object);
+
+  switch (property_id) {
+    case PROP_DISPLAY:
+      g_value_set_object (value, filter->display);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+  }
+}
+
+static void
+gst_vaapi_filter_class_init (GstVaapiFilterClass * klass)
+{
+  GObjectClass *const object_class = G_OBJECT_CLASS (klass);
+
+  object_class->set_property = gst_vaapi_filter_set_property;
+  object_class->get_property = gst_vaapi_filter_get_property;
+  object_class->finalize = gst_vaapi_filter_finalize;
+
+  /**
+   * GstVaapiFilter:display:
+   *
+   * #GstVaapiDisplay to be used.
+   */
+  g_object_class_install_property (object_class, PROP_DISPLAY,
+      g_param_spec_object ("display", "Gst VA-API Display",
+          "The VA-API display object to use", GST_TYPE_VAAPI_DISPLAY,
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME));
 }
-#endif
 
 /**
  * gst_vaapi_filter_new:
@@ -1128,62 +1166,19 @@ gst_vaapi_filter_class (void)
 GstVaapiFilter *
 gst_vaapi_filter_new (GstVaapiDisplay * display)
 {
-#if USE_VA_VPP
   GstVaapiFilter *filter;
 
-  filter = (GstVaapiFilter *)
-      gst_vaapi_mini_object_new0 (gst_vaapi_filter_class ());
-  if (!filter)
-    return NULL;
-
-  if (!gst_vaapi_filter_init (filter, display))
+  filter = g_object_new (GST_TYPE_VAAPI_FILTER, "display", display, NULL);
+  if (!gst_vaapi_filter_initialize (filter))
     goto error;
   return filter;
 
   /* ERRORS */
 error:
   {
-    gst_vaapi_filter_unref (filter);
+    gst_object_unref (filter);
     return NULL;
   }
-#else
-  GST_WARNING ("video processing is not supported, "
-      "please consider an upgrade to VA-API >= 0.34");
-  return NULL;
-#endif
-}
-
-/**
- * gst_vaapi_filter_ref:
- * @filter: a #GstVaapiFilter
- *
- * Atomically increases the reference count of the given @filter by one.
- *
- * Returns: The same @filter argument
- */
-GstVaapiFilter *
-gst_vaapi_filter_ref (GstVaapiFilter * filter)
-{
-  g_return_val_if_fail (filter != NULL, NULL);
-
-  return
-      GST_VAAPI_FILTER (gst_vaapi_mini_object_ref (GST_VAAPI_MINI_OBJECT
-          (filter)));
-}
-
-/**
- * gst_vaapi_filter_unref:
- * @filter: a #GstVaapiFilter
- *
- * Atomically decreases the reference count of the @filter by one. If
- * the reference count reaches zero, the filter will be free'd.
- */
-void
-gst_vaapi_filter_unref (GstVaapiFilter * filter)
-{
-  g_return_if_fail (filter != NULL);
-
-  gst_vaapi_mini_object_unref (GST_VAAPI_MINI_OBJECT (filter));
 }
 
 /**
@@ -1201,8 +1196,7 @@ gst_vaapi_filter_replace (GstVaapiFilter ** old_filter_ptr,
 {
   g_return_if_fail (old_filter_ptr != NULL);
 
-  gst_vaapi_mini_object_replace ((GstVaapiMiniObject **) old_filter_ptr,
-      GST_VAAPI_MINI_OBJECT (new_filter));
+  gst_object_replace ((GstObject **) old_filter_ptr, GST_OBJECT (new_filter));
 }
 
 /**
@@ -1294,7 +1288,6 @@ gboolean
 gst_vaapi_filter_set_operation (GstVaapiFilter * filter, GstVaapiFilterOp op,
     const GValue * value)
 {
-#if USE_VA_VPP
   GstVaapiFilterOpData *op_data;
 
   g_return_val_if_fail (filter != NULL, FALSE);
@@ -1340,7 +1333,6 @@ gst_vaapi_filter_set_operation (GstVaapiFilter * filter, GstVaapiFilterOp op,
     default:
       break;
   }
-#endif
   return FALSE;
 }
 
@@ -1363,7 +1355,6 @@ static GstVaapiFilterStatus
 gst_vaapi_filter_process_unlocked (GstVaapiFilter * filter,
     GstVaapiSurface * src_surface, GstVaapiSurface * dst_surface, guint flags)
 {
-#if USE_VA_VPP
   VAProcPipelineParameterBuffer *pipeline_param = NULL;
   VABufferID pipeline_param_buf_id = VA_INVALID_ID;
   VABufferID filters[N_PROPERTIES];
@@ -1503,8 +1494,6 @@ error:
     vaapi_destroy_buffer (filter->va_display, &pipeline_param_buf_id);
     return GST_VAAPI_FILTER_STATUS_ERROR_OPERATION_FAILED;
   }
-#endif
-  return GST_VAAPI_FILTER_STATUS_ERROR_UNSUPPORTED_OPERATION;
 }
 
 GstVaapiFilterStatus
@@ -1853,11 +1842,8 @@ static inline gfloat
 op_get_float_default_value (GstVaapiFilter * filter,
     GstVaapiFilterOpData * op_data)
 {
-#if USE_VA_VPP
   GParamSpecFloat *const pspec = G_PARAM_SPEC_FLOAT (op_data->pspec);
   return pspec->default_value;
-#endif
-  return 0.0;
 }
 
 gfloat
