@@ -28,6 +28,13 @@
 
 G_BEGIN_DECLS
 
+#define GST_TYPE_VAAPI_FILTER \
+    (gst_vaapi_filter_get_type ())
+#define GST_VAAPI_FILTER(obj) \
+    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_VAAPI_FILTER, GstVaapiFilter))
+#define GST_VAAPI_IS_FILTER(obj) \
+    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_VAAPI_FILTER))
+
 typedef struct _GstVaapiFilter                  GstVaapiFilter;
 typedef struct _GstVaapiFilterOpInfo            GstVaapiFilterOpInfo;
 
@@ -167,15 +174,12 @@ gst_vaapi_deinterlace_method_get_type (void) G_GNUC_CONST;
 GType
 gst_vaapi_deinterlace_flags_get_type (void) G_GNUC_CONST;
 
+GType
+gst_vaapi_filter_get_type (void) G_GNUC_CONST;
+
 GstVaapiFilter *
 gst_vaapi_filter_new (GstVaapiDisplay * display);
 
-GstVaapiFilter *
-gst_vaapi_filter_ref (GstVaapiFilter * filter);
-
-void
-gst_vaapi_filter_unref (GstVaapiFilter * filter);
-
 void
 gst_vaapi_filter_replace (GstVaapiFilter ** old_filter_ptr,
     GstVaapiFilter * new_filter);
@@ -269,4 +273,9 @@ gst_vaapi_filter_get_scaling_default (GstVaapiFilter * filter);
 
 gboolean
 gst_vaapi_filter_get_skintone_default (GstVaapiFilter * filter);
+
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVaapiFilter, gst_object_unref)
+#endif
+
 #endif /* GST_VAAPI_FILTER_H */
