@@ -86,7 +86,7 @@ gst_vaapi_surface_destroy (GstVaapiSurface * surface)
         &surface_id, 1);
     GST_VAAPI_DISPLAY_UNLOCK (display);
     if (!vaapi_check_status (status, "vaDestroySurfaces()"))
-      g_warning ("failed to destroy surface %" GST_VAAPI_ID_FORMAT,
+      GST_WARNING ("failed to destroy surface %" GST_VAAPI_ID_FORMAT,
           GST_VAAPI_ID_ARGS (surface_id));
     GST_VAAPI_OBJECT_ID (surface) = VA_INVALID_SURFACE;
   }
@@ -132,7 +132,6 @@ static gboolean
 gst_vaapi_surface_create_full (GstVaapiSurface * surface,
     const GstVideoInfo * vip, guint flags)
 {
-#if VA_CHECK_VERSION(0,34,0)
   GstVaapiDisplay *const display = GST_VAAPI_OBJECT_DISPLAY (surface);
   const GstVideoFormat format = GST_VIDEO_INFO_FORMAT (vip);
   VASurfaceID surface_id;
@@ -219,16 +218,12 @@ error_unsupported_format:
   GST_ERROR ("unsupported format %s",
       gst_vaapi_video_format_to_string (format));
   return FALSE;
-#else
-  return FALSE;
-#endif
 }
 
 static gboolean
 gst_vaapi_surface_create_from_buffer_proxy (GstVaapiSurface * surface,
     GstVaapiBufferProxy * proxy, const GstVideoInfo * vip)
 {
-#if VA_CHECK_VERSION (0,36,0)
   GstVaapiDisplay *const display = GST_VAAPI_OBJECT_DISPLAY (surface);
   GstVideoFormat format;
   VASurfaceID surface_id;
@@ -308,14 +303,56 @@ error_unsupported_format:
   GST_ERROR ("unsupported format %s",
       gst_vaapi_video_format_to_string (format));
   return FALSE;
-#else
-  return FALSE;
-#endif
 }
 
 #define gst_vaapi_surface_finalize gst_vaapi_surface_destroy
 GST_VAAPI_OBJECT_DEFINE_CLASS (GstVaapiSurface, gst_vaapi_surface);
 
+/**
+ * gst_vaapi_surface_new_from_formats:
+ * @display: a #GstVaapiDisplay
+ * @chroma_type: the surface chroma format
+ * @width: the requested surface width
+ * @height: the requested surface height
+ * @formats: the limited format list
+ *
+ * Creates a new #GstVaapiSurface with a @chroma_type valid for any
+ * format in @formats; If there aren't any, the returned surface is
+ * created forcing the passed @chroma_type.
+ *
+ * Return value: the newly allocated #GstVaapiSurface object
+ */
+GstVaapiSurface *
+gst_vaapi_surface_new_from_formats (GstVaapiDisplay * display,
+    GstVaapiChromaType chroma_type, guint width, guint height, GArray * formats)
+{
+  GstVaapiSurface *surface;
+  guint i;
+
+  for (i = 0; i < formats->len; i++) {
+    GstVideoFormat format = g_array_index (formats, GstVideoFormat, i);
+    if (format == gst_vaapi_video_format_from_chroma (chroma_type))
+      return gst_vaapi_surface_new (display, chroma_type, width, height);
+  }
+
+  /* Fallback: if there's no format valid for the chroma type let's
+   * just use the passed chroma */
+  surface = gst_vaapi_object_new (gst_vaapi_surface_class (), display);
+  if (!surface)
+    return NULL;
+  if (!gst_vaapi_surface_create (surface, chroma_type, width, height))
+    goto error;
+
+  return surface;
+
+  /* ERRORS */
+error:
+  {
+    gst_vaapi_object_unref (surface);
+    return NULL;
+  }
+}
+
 /**
  * gst_vaapi_surface_new:
  * @display: a #GstVaapiDisplay
@@ -340,6 +377,18 @@ gst_vaapi_surface_new (GstVaapiDisplay * display,
   if (!surface)
     return NULL;
 
+  /* first try a recent version of vaCreateSurface, and later use as
+   * fallback its old version */
+  {
+    GstVideoInfo vi;
+    GstVideoFormat surface_format;
+
+    surface_format = gst_vaapi_video_format_from_chroma (chroma_type);
+    gst_video_info_set_format (&vi, surface_format, width, height);
+
+    if (gst_vaapi_surface_create_full (surface, &vi, 0))
+      return surface;
+  }
   if (!gst_vaapi_surface_create (surface, chroma_type, width, height))
     goto error;
   return surface;
