@@ -61,11 +61,17 @@ G_BEGIN_DECLS
  * @GST_VAAPI_CHROMA_TYPE_YUV422: YUV 4:2:2 chroma format
  * @GST_VAAPI_CHROMA_TYPE_YUV444: YUV 4:4:4 chroma format
  * @GST_VAAPI_CHROMA_TYPE_YUV411: YUV 4:1:1 chroma format
- * @GST_VAAPI_CHROMA_TYPE_YUV410: YUV 4:1:0 chroma format
  * @GST_VAAPI_CHROMA_TYPE_YUV400: YUV 4:0:0 chroma format (grayscale)
- * @GST_VAAPI_CHROMA_TYPE_RGB32: 32-bit RGB chroma format
+ * @GST_VAAPI_CHROMA_TYPE_YUV420_10BPP: YUV 4:2:0 chroma format, 10 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_YUV422_10BPP: YUV 4:2:2 chroma format, 10 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_YUV444_10BPP: YUV 4:4:4 chroma format, 10 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_YUV420_12BPP: YUV 4:2:0 chroma format, 12 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_YUV422_12BPP: YUV 4:2:2 chroma format, 12 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_YUV444_12BPP: YUV 4:4:4 chroma format, 12 bits per channel
  * @GST_VAAPI_CHROMA_TYPE_RGB16: 16-bit RGB chroma format
- * @GST_VAAPI_CHROMA_TYPE_YUV420_10BPP: YUV 4:2:0 chroma format, more than 8 bits per channel
+ * @GST_VAAPI_CHROMA_TYPE_RGB32: 32-bit RGB chroma format
+ * @GST_VAAPI_CHROMA_TYPE_RGBP: Planar RGB, 8 bits per colour sample.
+ * @GST_VAAPI_CHROMA_TYPE_RGB32_10BPP: 32-bit RGB chroma format, 10 bits per colour sample
  *
  * The set of all chroma types for #GstVaapiSurface.
  */
@@ -75,11 +81,17 @@ typedef enum
   GST_VAAPI_CHROMA_TYPE_YUV422,
   GST_VAAPI_CHROMA_TYPE_YUV444,
   GST_VAAPI_CHROMA_TYPE_YUV411,
-  GST_VAAPI_CHROMA_TYPE_YUV410,
   GST_VAAPI_CHROMA_TYPE_YUV400,
-  GST_VAAPI_CHROMA_TYPE_RGB32,
+  GST_VAAPI_CHROMA_TYPE_YUV420_10BPP,
+  GST_VAAPI_CHROMA_TYPE_YUV422_10BPP,
+  GST_VAAPI_CHROMA_TYPE_YUV444_10BPP,
+  GST_VAAPI_CHROMA_TYPE_YUV420_12BPP,
+  GST_VAAPI_CHROMA_TYPE_YUV422_12BPP,
+  GST_VAAPI_CHROMA_TYPE_YUV444_12BPP,
   GST_VAAPI_CHROMA_TYPE_RGB16,
-  GST_VAAPI_CHROMA_TYPE_YUV420_10BPP
+  GST_VAAPI_CHROMA_TYPE_RGB32,
+  GST_VAAPI_CHROMA_TYPE_RGBP,
+  GST_VAAPI_CHROMA_TYPE_RGB32_10BPP,
 } GstVaapiChromaType;
 
 /**
@@ -169,6 +181,10 @@ typedef enum
 typedef struct _GstVaapiSurface                 GstVaapiSurface;
 typedef struct _GstVaapiSurfaceProxy            GstVaapiSurfaceProxy;
 
+GstVaapiSurface *
+gst_vaapi_surface_new_from_formats (GstVaapiDisplay * display,
+    GstVaapiChromaType chroma_type, guint width, guint height, GArray * formts);
+
 GstVaapiSurface *
 gst_vaapi_surface_new (GstVaapiDisplay * display,
     GstVaapiChromaType chroma_type, guint width, guint height);
