@@ -34,12 +34,12 @@
 #define DEBUG 1
 #include "gstvaapidebug.h"
 
-#define CONCAT(a, b)    CONCAT_(a, b)
-#define CONCAT_(a, b)   a##b
-#define STRINGIFY(x)    STRINGIFY_(x)
-#define STRINGIFY_(x)   #x
-#define STRCASEP(p, x)  STRCASE(CONCAT(p, x))
-#define STRCASE(x)      case x: return STRINGIFY(x)
+/* string case an enum */
+#define STRCASEP(p, x)  STRCASE(G_PASTE(p, x))
+#define STRCASE(x)      case x: return G_STRINGIFY(x)
+
+/* string case a macro */
+#define STRCASEM(p, x)  case G_PASTE(p, x): return G_STRINGIFY(x)
 
 #if VA_CHECK_VERSION (0,40,0)
 static gchar *
@@ -298,7 +298,7 @@ string_of_va_chroma_format (guint chroma_format)
 {
   switch (chroma_format) {
 #define MAP(value) \
-        STRCASEP(VA_RT_FORMAT_, value)
+        STRCASEM(VA_RT_FORMAT_, value)
       MAP (YUV420);
       MAP (YUV422);
       MAP (YUV444);
