@@ -23,17 +23,30 @@
 #ifndef GST_VAAPI_WINDOW_EGL_H
 #define GST_VAAPI_WINDOW_EGL_H
 
+#include <gst/gst.h>
 #include <gst/vaapi/gstvaapidisplay.h>
 #include <gst/vaapi/gstvaapiwindow.h>
 
 G_BEGIN_DECLS
 
+#define GST_TYPE_VAAPI_WINDOW_EGL (gst_vaapi_window_egl_get_type ())
 #define GST_VAAPI_WINDOW_EGL(obj) \
-    ((GstVaapiWindowEGL *)(obj))
+    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_VAAPI_WINDOW_EGL, GstVaapiWindowEGL))
+#define GST_VAAPI_IS_WINDOW_EGL(obj) \
+    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_VAAPI_WINDOW_EGL))
+
+typedef struct _GstVaapiWindowEGL GstVaapiWindowEGL;
+
+GType
+gst_vaapi_window_egl_get_type (void) G_GNUC_CONST;
 
 GstVaapiWindow *
 gst_vaapi_window_egl_new (GstVaapiDisplay * display, guint width, guint height);
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstVaapiWindowEGL, gst_object_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* GST_VAAPI_WINDOW_EGL_H */
