@@ -70,16 +70,10 @@ static const char gst_vaapidecode_sink_caps_str[] =
     GST_CAPS_CODEC("video/x-xvid")
     GST_CAPS_CODEC("video/x-h263")
     GST_CAPS_CODEC("video/x-h264")
-#if USE_H265_DECODER
     GST_CAPS_CODEC("video/x-h265")
-#endif
     GST_CAPS_CODEC("video/x-wmv")
-#if USE_VP8_DECODER
     GST_CAPS_CODEC("video/x-vp8")
-#endif
-#if USE_VP9_DECODER
     GST_CAPS_CODEC("video/x-vp9")
-#endif
     ;
 
 static const char gst_vaapidecode_src_caps_str[] =
@@ -87,7 +81,7 @@ static const char gst_vaapidecode_src_caps_str[] =
 #if (USE_GLX || USE_EGL)
     GST_VAAPI_MAKE_GLTEXUPLOAD_CAPS ";"
 #endif
-    GST_VIDEO_CAPS_MAKE("{ NV12, I420, YV12, P010_10LE }") ";"
+    GST_VIDEO_CAPS_MAKE("{ NV12, I420, YV12, YUY2, UYVY, Y210, P010_10LE, AYUV, Y410 }") ";"
     GST_VAAPI_MAKE_DMABUF_CAPS;
 
 static GstStaticPadTemplate gst_vaapidecode_src_factory =
@@ -110,9 +104,7 @@ struct _GstVaapiDecoderMap
 };
 
 static const GstVaapiDecoderMap vaapi_decode_map[] = {
-#if USE_JPEG_DECODER
   {GST_VAAPI_CODEC_JPEG, GST_RANK_MARGINAL, "jpeg", "image/jpeg", NULL},
-#endif
   {GST_VAAPI_CODEC_MPEG2, GST_RANK_PRIMARY, "mpeg2",
       "video/mpeg, mpegversion=2, systemstream=(boolean)false", NULL},
   {GST_VAAPI_CODEC_MPEG4, GST_RANK_PRIMARY, "mpeg4",
@@ -122,15 +114,9 @@ static const GstVaapiDecoderMap vaapi_decode_map[] = {
       gst_vaapi_decode_h264_install_properties},
   {GST_VAAPI_CODEC_VC1, GST_RANK_PRIMARY, "vc1",
       "video/x-wmv, wmvversion=3, format={WMV3,WVC1}", NULL},
-#if USE_VP8_DECODER
   {GST_VAAPI_CODEC_VP8, GST_RANK_PRIMARY, "vp8", "video/x-vp8", NULL},
-#endif
-#if USE_VP9_DECODER
   {GST_VAAPI_CODEC_VP9, GST_RANK_PRIMARY, "vp9", "video/x-vp9", NULL},
-#endif
-#if USE_H265_DECODER
   {GST_VAAPI_CODEC_H265, GST_RANK_PRIMARY, "h265", "video/x-h265", NULL},
-#endif
   {0 /* the rest */ , GST_RANK_PRIMARY + 1, NULL,
       gst_vaapidecode_sink_caps_str, NULL},
 };
@@ -764,6 +750,11 @@ error_decode:
         ret = GST_FLOW_OK;
         GST_VIDEO_DECODER_ERROR (vdec, 1, STREAM, DECODE, ("Decoding error"),
             ("Decode error %d", status), ret);
+        GST_INFO ("requesting upstream a key unit");
+        gst_pad_push_event (GST_VIDEO_DECODER_SINK_PAD (decode),
+            gst_video_event_new_upstream_force_key_unit (GST_CLOCK_TIME_NONE,
+                FALSE, 0));
+        ret = GST_FLOW_OK;
         break;
     }
     gst_video_decoder_drop_frame (vdec, frame);
@@ -918,7 +909,6 @@ gst_vaapidecode_create (GstVaapiDecode * decode, GstCaps * caps)
         }
       }
       break;
-#if USE_H265_DECODER
     case GST_VAAPI_CODEC_H265:
       decode->decoder = gst_vaapi_decoder_h265_new (dpy, caps);
 
@@ -940,26 +930,19 @@ gst_vaapidecode_create (GstVaapiDecode * decode, GstCaps * caps)
         }
       }
       break;
-#endif
     case GST_VAAPI_CODEC_WMV3:
     case GST_VAAPI_CODEC_VC1:
       decode->decoder = gst_vaapi_decoder_vc1_new (dpy, caps);
       break;
-#if USE_JPEG_DECODER
     case GST_VAAPI_CODEC_JPEG:
       decode->decoder = gst_vaapi_decoder_jpeg_new (dpy, caps);
       break;
-#endif
-#if USE_VP8_DECODER
     case GST_VAAPI_CODEC_VP8:
       decode->decoder = gst_vaapi_decoder_vp8_new (dpy, caps);
       break;
-#endif
-#if USE_VP9_DECODER
     case GST_VAAPI_CODEC_VP9:
       decode->decoder = gst_vaapi_decoder_vp9_new (dpy, caps);
       break;
-#endif
     default:
       decode->decoder = NULL;
       break;
@@ -1087,7 +1070,10 @@ gst_vaapidecode_start (GstVideoDecoder * vdec)
   success =
       gst_vaapi_plugin_base_ensure_display (GST_VAAPI_PLUGIN_BASE (decode));
   if (old_display)
-    gst_vaapi_display_unref (old_display);
+    gst_object_unref (old_display);
+
+  /* Disable errors on decode errors */
+  gst_video_decoder_set_max_errors (vdec, -1);
 
   return success;
 }
@@ -1177,9 +1163,15 @@ gst_vaapidecode_parse_frame (GstVideoDecoder * vdec,
       decode->current_frame_size = 0;
       break;
     default:
-      GST_ERROR ("parse error %d", status);
-      ret = GST_FLOW_EOS;
+      GST_WARNING ("parse error %d", status);
+      /* just keep parsing, the decoder should have flushed the broken unit */
+      ret = GST_VAAPI_DECODE_FLOW_PARSE_DATA;
       decode->current_frame_size = 0;
+
+      GST_INFO ("requesting upstream a key unit");
+      gst_pad_push_event (GST_VIDEO_DECODER_SINK_PAD (decode),
+          gst_video_event_new_upstream_force_key_unit (GST_CLOCK_TIME_NONE,
+              FALSE, 0));
       break;
   }
   return ret;
@@ -1273,6 +1265,13 @@ gst_vaapidecode_ensure_allowed_sinkpad_caps (GstVaapiDecode * decode)
     have_high |= profile == GST_VAAPI_PROFILE_H264_HIGH;
   }
 
+  if (have_high) {
+    allowed_sinkpad_caps =
+        add_h264_profile_in_caps (allowed_sinkpad_caps, "progressive-high");
+    allowed_sinkpad_caps =
+        add_h264_profile_in_caps (allowed_sinkpad_caps, "constrained-high");
+  }
+
   if (base_only && (!have_mvc || !have_svc) && have_high) {
     if (!have_mvc) {
       GST_DEBUG ("base_only: force adding MVC profiles in caps");
@@ -1477,7 +1476,7 @@ gst_vaapidecode_class_init (GstVaapiDecodeClass * klass)
 
   element_class->set_context = gst_vaapi_base_set_context;
   gst_element_class_set_static_metadata (element_class, longname,
-      "Codec/Decoder/Video", description,
+      "Codec/Decoder/Video/Hardware", description,
       "Gwenole Beauchesne <gwenole.beauchesne@intel.com>, "
       "Halley Zhao <halley.zhao@intel.com>, "
       "Sreerenj Balachandran <sreerenj.balachandran@intel.com>, "
