@@ -38,11 +38,11 @@
  * If #GstVaapiEncodeH264:dct8x8 is enabled, then High profile is
  * used.  Otherwise, if #GstVaapiEncodeH264:cabac entropy coding is
  * enabled or #GstVaapiEncodeH264:max-bframes are allowed, then Main
- * Profile is in effect, and otherwise Baseline profile applies.  The
- * high profile is imposed by default, which is fine for most software
- * players and settings, but in some cases (e.g. hardware platforms) a
- * more restricted profile/level may be necessary. The recommended way
- * to set a profile is to set it in the downstream caps.
+ * Profile is in effect. The element will alway go with the maximal
+ * profile available in the caps negotation and otherwise Baseline
+ * profile applies. But in some cases (e.g. hardware platforms) a more
+ * restrictedprofile/level may be necessary. The recommended way to
+ * set a profile is to set it in the downstream caps.
  *
  * You can also set parameters to adjust the latency of encoding:
  * #GstVaapiEncodeH264:quality-level is a number between 1-7, in the
@@ -327,9 +327,9 @@ gst_vaapiencode_h264_set_config (GstVaapiEncode * base_encode)
 
     } else {
       GstCaps *profile_caps;
-
       profile_caps = gst_caps_intersect (allowed_caps, available_caps);
       profile = find_best_profile (profile_caps);
+
       gst_caps_unref (profile_caps);
     }
 
@@ -593,7 +593,7 @@ gst_vaapiencode_h264_class_init (GstVaapiEncodeH264Class * klass)
 
   gst_element_class_set_static_metadata (element_class,
       "VA-API H264 encoder",
-      "Codec/Encoder/Video",
+      "Codec/Encoder/Video/Hardware",
       GST_PLUGIN_DESC, "Wind Yuan <feng.yuan@intel.com>");
 
   /* sink pad */
