@@ -57,7 +57,7 @@ plugin_set_display (GstVaapiPluginBase * plugin, GstVaapiDisplay * display)
     plugin->display_type = gst_vaapi_display_get_display_type (display);
     gst_vaapi_plugin_base_set_display_name (plugin, display_name);
   }
-  gst_vaapi_display_unref (display);
+  gst_object_unref (display);
 }
 
 /**
@@ -1315,6 +1315,9 @@ extract_allowed_surface_formats (GstVaapiDisplay * display,
       gst_vaapi_object_replace (&surface, NULL);
   }
 
+  if (surface)
+    gst_vaapi_object_unref (surface);
+
   if (out_formats->len == 0) {
     g_array_unref (out_formats);
     return NULL;
@@ -1335,7 +1338,7 @@ ensure_allowed_raw_caps (GstVaapiPluginBase * plugin, GstVideoFormat format,
     return TRUE;
 
   out_formats = NULL;
-  display = gst_vaapi_display_ref (plugin->display);
+  display = gst_object_ref (plugin->display);
   formats = gst_vaapi_display_get_image_formats (display);
   if (!formats)
     goto bail;
@@ -1356,7 +1359,7 @@ bail:
     g_array_unref (formats);
   if (out_formats)
     g_array_unref (out_formats);
-  gst_vaapi_display_unref (display);
+  gst_object_unref (display);
 
   return ret;
 }
@@ -1409,7 +1412,7 @@ void
 gst_vaapi_plugin_base_set_srcpad_can_dmabuf (GstVaapiPluginBase * plugin,
     GstObject * object)
 {
-#if VA_CHECK_VERSION (0,36,0) && USE_EGL && USE_GST_GL_HELPERS
+#if USE_EGL && USE_GST_GL_HELPERS
   GstGLContext *const gl_context = GST_GL_CONTEXT (object);
 
   plugin->srcpad_can_dmabuf =
