@@ -105,7 +105,7 @@ gst_vaapi_caps_feature_contains (const GstCaps * caps,
 
 #define GST_VAAPI_MAKE_SURFACE_CAPS					\
     GST_VIDEO_CAPS_MAKE_WITH_FEATURES(					\
-        GST_CAPS_FEATURE_MEMORY_VAAPI_SURFACE, "{ ENCODED, NV12, I420, YV12, P010_10LE }")
+        GST_CAPS_FEATURE_MEMORY_VAAPI_SURFACE, "{ ENCODED, NV12, I420, YV12, YUY2, UYVY, Y210, P010_10LE, AYUV, Y410 }")
 
 #define GST_VAAPI_MAKE_GLTEXUPLOAD_CAPS				\
     GST_VIDEO_CAPS_MAKE_WITH_FEATURES(					\
