@@ -439,6 +439,35 @@ gst_vaapisink_x11_handle_events (GstVaapiSink * sink)
     }
     if (do_expose)
       gst_vaapisink_video_overlay_expose (GST_VIDEO_OVERLAY (sink));
+
+    /* Handle Display events */
+    for (;;) {
+      gst_vaapi_display_lock (display);
+      if (XPending (x11_dpy) == 0) {
+        gst_vaapi_display_unlock (display);
+        break;
+      }
+      XNextEvent (x11_dpy, &e);
+      gst_vaapi_display_unlock (display);
+
+      switch (e.type) {
+        case ClientMessage:{
+          Atom wm_delete;
+
+          wm_delete = XInternAtom (x11_dpy, "WM_DELETE_WINDOW", False);
+          if (wm_delete == (Atom) e.xclient.data.l[0]) {
+            /* Handle window deletion by posting an error on the bus */
+            GST_ELEMENT_ERROR (sink, RESOURCE, NOT_FOUND,
+                ("Output window was closed"), (NULL));
+            return FALSE;
+          }
+          break;
+        }
+        default:
+          break;
+      }
+    }
+
   }
   return TRUE;
 }
@@ -504,6 +533,17 @@ gst_vaapisink_backend_x11 (void)
 #include <gst/vaapi/gstvaapidisplay_wayland.h>
 #include <gst/vaapi/gstvaapiwindow_wayland.h>
 
+static void
+on_window_wayland_size_changed (GstVaapiWindowWayland * window, gint width,
+    gint height, gpointer user_data)
+{
+  GstVaapiSink *sink = GST_VAAPISINK (user_data);
+
+  GST_DEBUG ("Wayland window size changed to: %dx%d", width, height);
+  gst_vaapisink_reconfigure_window (sink);
+  gst_vaapisink_show_frame (GST_VIDEO_SINK_CAST (sink), NULL);
+}
+
 static gboolean
 gst_vaapisink_wayland_create_window (GstVaapiSink * sink, guint width,
     guint height)
@@ -515,6 +555,10 @@ gst_vaapisink_wayland_create_window (GstVaapiSink * sink, guint width,
   sink->window = gst_vaapi_window_wayland_new (display, width, height);
   if (!sink->window)
     return FALSE;
+
+  g_signal_connect_object (sink->window, "size-changed",
+      G_CALLBACK (on_window_wayland_size_changed), sink, 0);
+
   return TRUE;
 }
 
