@@ -21,7 +21,6 @@
  */
 
 #include "gst/vaapi/sysdeps.h"
-#include <string.h>
 #include <gst/gst.h>
 #if USE_DRM
 # include <gst/vaapi/gstvaapidisplay_drm.h>
@@ -182,7 +181,7 @@ video_output_create_display (const gchar * display_name)
         if (display) {
           if (gst_vaapi_display_get_display (display))
             break;
-          gst_vaapi_display_unref (display);
+          gst_object_unref (display);
           display = NULL;
         }
       }
@@ -203,7 +202,7 @@ video_output_create_display (const gchar * display_name)
     egl_display = NULL;
     g_print ("error: unsupported EGL renderering mode\n");
 #endif
-    gst_vaapi_display_unref (display);
+    gst_object_unref (display);
     if (!egl_display)
       return NULL;
     display = egl_display;
