@@ -21,7 +21,6 @@
  */
 
 #include "gst/vaapi/sysdeps.h"
-#include <string.h>
 #include <gst/vaapi/gstvaapisurface.h>
 #include "decoder.h"
 #include "output.h"
@@ -164,9 +163,9 @@ main (int argc, char *argv[])
 
   gst_video_overlay_composition_unref (compo);
   gst_vaapi_surface_proxy_unref (proxy);
-  gst_vaapi_decoder_unref (decoder);
-  gst_vaapi_window_unref (window);
-  gst_vaapi_display_unref (display);
+  gst_object_unref (decoder);
+  gst_object_unref (window);
+  gst_object_unref (display);
   g_free (g_codec_str);
   video_output_exit ();
   return 0;
