@@ -131,11 +131,11 @@ main (int argc, char *argv[])
       g_error ("could not render surface");
 
     pause ();
-    gst_vaapi_window_unref (window);
+    gst_object_unref (window);
   }
 
   gst_vaapi_object_unref (surface);
-  gst_vaapi_display_unref (display);
+  gst_object_unref (display);
 #endif
 
 #if USE_X11
@@ -161,7 +161,7 @@ main (int argc, char *argv[])
       g_error ("could not render surface");
 
     pause ();
-    gst_vaapi_window_unref (window);
+    gst_object_unref (window);
   }
 
   g_print ("#\n");
@@ -194,13 +194,13 @@ main (int argc, char *argv[])
       g_error ("could not render surface");
 
     pause ();
-    gst_vaapi_window_unref (window);
+    gst_object_unref (window);
     XUnmapWindow (dpy, win);
     XDestroyWindow (dpy, win);
   }
 
   gst_vaapi_object_unref (surface);
-  gst_vaapi_display_unref (display);
+  gst_object_unref (display);
 #endif
 
 #if USE_WAYLAND
@@ -226,11 +226,11 @@ main (int argc, char *argv[])
       g_error ("could not render surface");
 
     pause ();
-    gst_vaapi_window_unref (window);
+    gst_object_unref (window);
   }
 
   gst_vaapi_object_unref (surface);
-  gst_vaapi_display_unref (display);
+  gst_object_unref (display);
 #endif
 
   gst_deinit ();
